==> gimp-3.0.8.tar.xz: gimp-3.0.8/app/core/gimpimage-preview.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_IMAGE_PREVIEW_H__
#define __GIMP_IMAGE_PREVIEW_H__


const Babl  * gimp_image_get_preview_format (GimpImage    *image);


/*
 *  virtual functions of GimpImage -- don't call directly
 */

void          gimp_image_get_preview_size   (GimpViewable *viewable,
                                             gint          size,
                                             gboolean      is_popup,
                                             gboolean      dot_for_dot,
                                             gint         *width,
                                             gint         *height);
gboolean      gimp_image_get_popup_size     (GimpViewable *viewable,
                                             gint          width,
                                             gint          height,
                                             gboolean      dot_for_dot,
                                             gint         *popup_width,
                                             gint         *popup_height);
GimpTempBuf * gimp_image_get_new_preview    (GimpViewable *viewable,
                                             GimpContext  *context,
                                             gint          width,
                                             gint          height,
                                             GeglColor    *fg_color);
GdkPixbuf   * gimp_image_get_new_pixbuf     (GimpViewable *viewable,
                                             GimpContext  *context,
                                             gint          width,
                                             gint          height,
                                             GeglColor    *fg_color);


#endif /* __GIMP_IMAGE_PREVIEW_H__ */

==> gimp-3.1.2.tar.xz: gimp-3.1.2/app/core/gimpimage-preview.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_IMAGE_PREVIEW_H__
#define __GIMP_IMAGE_PREVIEW_H__


const Babl  * gimp_image_get_preview_format (GimpImage    *image);


/*
 *  virtual functions of GimpImage -- don't call directly
 */

void          gimp_image_get_preview_size   (GimpViewable *viewable,
                                             gint          size,
                                             gboolean      is_popup,
                                             gboolean      dot_for_dot,
                                             gint         *width,
                                             gint         *height);
gboolean      gimp_image_get_popup_size     (GimpViewable *viewable,
                                             gint          width,
                                             gint          height,
                                             gboolean      dot_for_dot,
                                             gint         *popup_width,
                                             gint         *popup_height);
GimpTempBuf * gimp_image_get_new_preview    (GimpViewable *viewable,
                                             GimpContext  *context,
                                             gint          width,
                                             gint          height,
                                             GeglColor    *color,
                                             GeglColor    *background);
GdkPixbuf   * gimp_image_get_new_pixbuf     (GimpViewable *viewable,
                                             GimpContext  *context,
                                             gint          width,
                                             gint          height,
                                             GeglColor    *color,
                                             GeglColor    *background);


#endif /* __GIMP_IMAGE_PREVIEW_H__ */
